@@ -35,6 +35,7 @@ using Beagle.Util;
 
 namespace Beagle {
 
+	[Flags]
 	public enum QueryDomain {
 		Local        = 1,
 		System       = 2,
@@ -346,6 +347,11 @@ namespace Beagle {
 
 		///////////////////////////////////////////////////////////////
 
+		public QueryDomain QueryDomain {
+			get { return domainFlags; }
+			set { domainFlags = value; }
+		}
+
 		public void AddDomain (Beagle.QueryDomain d)
 		{
 			domainFlags |= d;
@@ -377,5 +383,15 @@ namespace Beagle {
 				      && mimeTypes.Count == 0
 				      && searchSources.Count == 0; }
 		}
+
+		public override string ToString ()
+		{
+			StringBuilder sb = new StringBuilder ();
+
+			foreach (QueryPart p in parts)
+				sb.Append (p.ToString () + "\n");
+
+			return sb.ToString ();
+		}
 	}
 }
