@@ -31,10 +31,16 @@ using Entagged;
 
 namespace Beagle.Filters {
 
+	[PropertyKeywordMapping (Keyword="album", PropertyName="fixme:album", IsKeyword=false)]
+	[PropertyKeywordMapping (Keyword="artist", PropertyName="fixme:artist", IsKeyword=false)]
+	[PropertyKeywordMapping (Keyword="genre", PropertyName="fixme:genre", IsKeyword=true)]
 	public class FilterMusic : Beagle.Daemon.Filter {
 	
 		public FilterMusic ()
 		{
+			// 1: Added duration and bitrate property
+			SetVersion (1);
+			
 			// APE / Monkeys Audio
 			AddSupportedFlavor (FilterFlavor.NewFromExtension (".ape"));
 
@@ -111,6 +117,9 @@ namespace Beagle.Filters {
 			foreach (string genre in tag.Genres)
 				AddProperty (Beagle.Property.NewKeyword ("fixme:genre", genre));
 
+			AddProperty (Beagle.Property.NewUnsearched ("fixme:duration", tag.Duration));
+			AddProperty (Beagle.Property.NewUnsearched ("fixme:bitrate", tag.Bitrate));
+
 			Finished ();
 		}
 	}
