@@ -518,8 +518,9 @@ namespace Beagle.Filters {
 					// And certain PPTs do have some slides in after
 					// "Document" container.
 					//Console.WriteLine ("Length of stream = {0}", stream.Size);
-					while (!stream.Eof) {
-						ParseElement (stream);
+					int ret = -1;
+					while (!stream.Eof && ret != 0) {
+						ret = ParseElement (stream);
 						//Console.WriteLine ("Position of the ptr in the stream: {0}", stream.Position);
 					}
 				} else {
@@ -551,7 +552,14 @@ namespace Beagle.Filters {
 					   ((dualStorTemp = file.ChildByName ("PowerPoint Document")) == null)) {
 					Logger.Log.Error ("{0} is a PPT 95/4.0 file.  Beagle does not support PPT 95 files. Skipping...", FileName);
 					Error ();
+					return;
 				}
+
+				if (file.ChildByName ("EncryptedSummary") != null) {
+					Log.Warn ("{0} is a password-protected PowerPoint file.  Skipping.", FileName);
+					Error ();
+				}
+
 			} catch (Exception e) {
 				
 				Logger.Log.Error ("Unable to open OleFile stream of "+info.FullName);
