@@ -26,48 +26,54 @@
 
 using System;
 using System.Collections;
+using System.Runtime.InteropServices;
 using System.Threading;
 
 namespace Beagle.Util {
 
 	public class ExceptionHandlingThread {
 
-		private static Hashtable live_threads = new Hashtable ();
+		private static ArrayList live_threads = new ArrayList ();
 		private Thread thread;
 		private ThreadStart method;
 
 		private ExceptionHandlingThread (ThreadStart method)
 		{
+			if (method == null)
+				throw new ArgumentNullException ("method");
+
 			this.method = method;
 		}
 
 		private void ThreadStarted ()
 		{
+			this.thread.Name = String.Format ("EHT {0:00000} {1}:{2}", wrap_gettid (), method.Target == null ? "(static)" : method.Target.ToString (), method.Method);
+
 			try {
 				this.method ();
+			} catch (ThreadAbortException e) {
+				Logger.Log.Debug ("{0}:\n{1}\n", this.thread.Name, e.StackTrace);
 			} catch (Exception e) {
-				Logger.Log.Warn ("Exception caught while executing {0}:{1}",
+				Logger.Log.Warn (e, "Exception caught while executing {0}:{1}",
 						 this.method.Target, this.method.Method);
-				Logger.Log.Warn (e);
 			}
 
 			lock (live_threads)
 				live_threads.Remove (this.thread);
 		}
 
-		public static void Start (ThreadStart method)
+		public static Thread Start (ThreadStart method)
 		{
 			ExceptionHandlingThread eht = new ExceptionHandlingThread (method);
 
 			eht.thread = new Thread (new ThreadStart (eht.ThreadStarted));
 
-			eht.thread.Name = String.Format ("ExceptionHandlingThread: {0}:{1}",
-							 method.Target, method.Method);
-
 			lock (live_threads)
-				live_threads [eht.thread] = eht.thread.Name;
+				live_threads.Add (eht.thread);
 
 			eht.thread.Start ();
+
+			return eht.thread;
 		}
 
 		public static void SpewLiveThreads ()
@@ -75,8 +81,8 @@ namespace Beagle.Util {
 			bool have_live_thread = false;
 
 			lock (live_threads) {
-				foreach (string str in live_threads.Values) {
-					Logger.Log.Debug ("Live ExceptionHandlingThread: {0}", str);
+				foreach (Thread t in live_threads) {
+					Logger.Log.Debug ("Live ExceptionHandlingThread: {0}", t.Name);
 					have_live_thread = true;
 				}
 			}
@@ -84,5 +90,22 @@ namespace Beagle.Util {
 			if (! have_live_thread)
 				Logger.Log.Debug ("No live ExceptionHandlingThreads!");
 		}
+
+		public static void AbortThreads ()
+		{
+			ArrayList cancel_threads = null;
+
+			// Copy the list to avoid recursively locking
+			lock (live_threads)
+				cancel_threads = (ArrayList) live_threads.Clone ();
+
+			foreach (Thread t in cancel_threads) {
+				Logger.Log.Debug ("Aborting thread: {0}", t.Name);
+				t.Abort ();
+			}
+		}
+
+		[DllImport ("libbeagleglue")]
+		static extern uint wrap_gettid ();
 	}
 }
