@@ -66,6 +66,15 @@ namespace Beagle.Daemon.EvolutionDataServerQueryable {
 		{
 			base.Start ();
 
+			// Defer the actual startup till main_loop starts.
+			// This will improve kill beagle while starting up.
+			// EDS requires StartWorker to run in mainloop,
+			// hence it is not started in a separate thread.
+			GLib.Idle.Add (new GLib.IdleHandler (delegate () { StartWorker (); return false;}));
+		}
+
+		private void StartWorker ()
+		{
 			Logger.Log.Info ("Scanning addressbooks and calendars");
 			Stopwatch timer = new Stopwatch ();
 			timer.Start ();
@@ -84,7 +93,7 @@ namespace Beagle.Daemon.EvolutionDataServerQueryable {
 				new SourcesHandler ("/apps/evolution/calendar/sources", typeof (CalContainer), this, Driver.Fingerprint);
 				success = true;
 			} catch (DllNotFoundException ex) {
-				Logger.Log.Error ("Unable to start EvolutionDataServer backend: Unable to find or open {0}", ex.Message);
+				Logger.Log.Error (ex, "Unable to start EvolutionDataServer backend: Unable to find or open libraries:");
 			} finally {
 				State = QueryableState.Idle;
 				timer.Stop ();
