@@ -26,8 +26,8 @@
 
 //
 // This queryable just takes the LuceneQueryable and adds some sane
-// default behavior for indexing files.
-//
+// default behavior for indexing files containing multiple indexables.
+// Suitable for feedfiles or mbox style mail files.
 
 using System;
 using System.Collections;
@@ -168,7 +168,7 @@ namespace Beagle.Daemon {
 			}
 
 			if (! FileAttributesStore.Write (attr))
-				Logger.Log.Error ("Couldn't write attributes for {0}", info.Path);
+				Logger.Log.Warn ("Couldn't write attributes for {0}", info.Path);
 
 			file_info_cache.Remove (info.Uri);
 		}
